@@ -338,7 +338,6 @@ static void
 eog_thumb_nav_init (EogThumbNav *nav)
 {
 	EogThumbNavPrivate *priv;
-	GtkWidget *arrow;
 
 	gtk_orientable_set_orientation (GTK_ORIENTABLE (nav),
 					GTK_ORIENTATION_HORIZONTAL);
@@ -351,15 +350,11 @@ eog_thumb_nav_init (EogThumbNav *nav)
 
 	priv->show_buttons = TRUE;
 
-        priv->button_left = gtk_button_new ();
+	priv->button_left = gtk_button_new_from_icon_name ("go-previous-symbolic",
+							   GTK_ICON_SIZE_BUTTON);
 	gtk_button_set_relief (GTK_BUTTON (priv->button_left), GTK_RELIEF_NONE);
 
-	arrow = gtk_image_new_from_icon_name ("pan-start-symbolic", GTK_ICON_SIZE_BUTTON);
-	gtk_container_add (GTK_CONTAINER (priv->button_left), arrow);
-
-	gtk_widget_set_size_request (GTK_WIDGET (priv->button_left), 25, 0);
-
-        gtk_box_pack_start (GTK_BOX (nav), priv->button_left, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (nav), priv->button_left, FALSE, FALSE, 0);
 
 	g_signal_connect (priv->button_left,
 			  "clicked",
@@ -405,17 +400,13 @@ eog_thumb_nav_init (EogThumbNav *nav)
 			  G_CALLBACK (eog_thumb_nav_adj_value_changed),
 			  nav);
 
-        gtk_box_pack_start (GTK_BOX (nav), priv->sw, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (nav), priv->sw, TRUE, TRUE, 0);
 
-        priv->button_right = gtk_button_new ();
+	priv->button_right = gtk_button_new_from_icon_name ("go-next-symbolic",
+							    GTK_ICON_SIZE_BUTTON);
 	gtk_button_set_relief (GTK_BUTTON (priv->button_right), GTK_RELIEF_NONE);
 
-	arrow = gtk_image_new_from_icon_name ("pan-end-symbolic", GTK_ICON_SIZE_BUTTON);
-	gtk_container_add (GTK_CONTAINER (priv->button_right), arrow);
-
-	gtk_widget_set_size_request (GTK_WIDGET (priv->button_right), 25, 0);
-
-        gtk_box_pack_start (GTK_BOX (nav), priv->button_right, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (nav), priv->button_right, FALSE, FALSE, 0);
 
 	g_signal_connect (priv->button_right,
 			  "clicked",
